@@ -1,4 +1,4 @@
-# Copyright 2017-2021 QuantRocket LLC - All Rights Reserved
+# Copyright 2017-2022 QuantRocket LLC - All Rights Reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from moonshot.commission import PercentageCommission
+from moonshot.commission.base import PercentageCommission
 
 class SpotFXCommission(PercentageCommission):
     """
